==> lxqt-panel-2.1.3.tar.xz: lxqt-panel-2.1.3/plugin-fancymenu/translations/fancymenu_en_GB.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_GB">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Show/hide main menu</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation>Favourites</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="56"/>
        <source>All Applications</source>
        <translation>All Applications</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="155"/>
        <source>Search...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="161"/>
        <source>LXQt Configuration Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="167"/>
        <source>Leave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="173"/>
        <source>About LXQt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="191"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="357"/>
        <source>Add to desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="365"/>
        <source>Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="366"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="372"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="373"/>
        <source>The file cannot be overwritten.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="380"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="393"/>
        <source>Remove from Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="400"/>
        <source>Add to Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="716"/>
        <source>No Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="717"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.1.4.orig.tar.xz: lxqt-panel-2.1.4/plugin-fancymenu/translations/fancymenu_en_GB.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_GB">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Show/hide main menu</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation>Favourites</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="56"/>
        <source>All Applications</source>
        <translation>All Applications</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu Settings</source>
        <translation>Fancy Menu Settings</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Icon:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Button text:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Custom font size:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation>Auto-select after:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation>Menu file</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation>Menu file:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="155"/>
        <source>Search...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="161"/>
        <source>LXQt Configuration Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="167"/>
        <source>Leave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="173"/>
        <source>About LXQt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="191"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="357"/>
        <source>Add to desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="365"/>
        <source>Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="366"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="372"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="373"/>
        <source>The file cannot be overwritten.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="380"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="393"/>
        <source>Remove from Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="400"/>
        <source>Add to Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="716"/>
        <source>No Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="717"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
